@@ -1756,7 +1756,7 @@ void BscrSM_updateDI1(gsl_vector *s1,
     
     int skip, i, j;
     int j_old, J_new, u;
-    double s_star, Upert, newLam;
+    double Upert, newLam;
     double logLH, logLH_prop, Del;
     double logPrior, logPrior_prop, logPriorR, logPropR;
     double logJacob, logR;
@@ -2294,7 +2294,7 @@ void BscrSM_updateDI2(gsl_vector *s2,
     
     int skip, i, j;
     int j_old, J_new, u;
-    double s_star, Upert, newLam;
+    double Upert, newLam;
     double logLH, logLH_prop, Del;
     double logPrior, logPrior_prop, logPriorR, logPropR;
     double logJacob, logR;
@@ -2833,7 +2833,7 @@ void BscrSM_updateDI3(gsl_vector *s3,
     
     int skip, i, j;
     int j_old, J_new, u;
-    double s_star, Upert, newLam;
+    double Upert, newLam;
     double logLH, logLH_prop, Del;
     double logPrior, logPrior_prop, logPriorR, logPropR;
     double logJacob, logR;
